from setuptools import setup
setup(name='MukeshTheBull',
version='0.3',
description='Welcome to Mukesh the Bulls world, full of milk and fun!!',
Long_description = 'Welcome to Mukesh the Bulls world, full of milk and fun!! Location at Ghaziabad Urban Forest, village Karhera. Sri Krishna Gaushala',
author='Friends of Cheeku',
packages = ['MukeshTheBull'],
install_requires=['Pillow'])
